@@ -14,7 +14,7 @@ use Net::RDAP::SearchResult;
 use vars qw($VERSION);
 use strict;
 
-$VERSION = 0.12;
+$VERSION = 0.13;
 
 =pod
 
@@ -197,6 +197,34 @@ sub autnum {
 	}
 }
 
+=pod
+
+=head2 Entity Lookup
+
+	$entity = $rdap->entity($handle);
+
+This method returns a L<Net::RDAP::Object::Entity> object containing
+information about the entity referenced by C<$handle>, which must be
+a string containing a "tagged" handle, such as C<ABC123-EXAMPLE>, as
+per RFC 8521.
+
+=cut
+
+sub entity {
+	my ($self, $object, %args) = @_;
+
+	if ($object !~ /-/) {
+		return $self->error(
+			'errorCode'	=> 400,
+			'title'		=> 'argument must be a tagged handle',
+		);
+
+	} else {
+		return $self->query('object' => $object, %args);
+
+	}
+}
+
 #
 # main method
 #
@@ -236,7 +264,7 @@ L<URI> or L<Net::RDAP::Link> object), and return a L<Net::RDAP::Object>
 object (assuming that the server returns a valid RDAP response). This
 method is used internally by C<query()> but is also available for when
 you need to directly fetch a resource without using the IANA
-registry, such as for nameserver or entity queries.
+registry, such as for nameserver or untagged entity queries.
 
 The third form allows the method to be called on an existing
 L<Net::RDAP::Object>. Objects which are embedded inside other
@@ -319,8 +347,8 @@ sub fetch {
 	#
 	# check and parse the response
 	#
-	if (304 == $response->code && -e $file) {
-		utime(undef, undef, $file);
+	if (-e $file && (304 == $response->code || ($response->code >= 500))) {
+		utime(undef, undef, $file) if (304 == $response->code);
 		return $self->object_from_response(decode_json(read_file($file)), $url);
 
 	} elsif ($response->is_error) {
@@ -603,6 +631,9 @@ Protocol (EPP) and Registration Data Access Protocol (RDAP) Status Mapping
 
 =item * L<https://tools.ietf.org/html/rfc8288> -  Web Linking
 
+=item * L<https://tools.ietf.org/html/rfc8521> -  Registration Data Access
+Protocol (RDAP) Object Tagging
+
 =back
 
 =head1 COPYRIGHT
